# aviationFormula
A collection of formula around aviation and the globe in python.

A documentation of the implemented formula will follow.

# Requirements
All formula should work with every version of python. Only basic modules (like `math`) are imported. For the future I want to avoid using 3rd party packages such as `numpy`.

# Credits
None of the formula in this package where derived or invented by me. The only thing I did was an implementation in python.

The raw formula (and an implementation in VBA) are published by Ed Williams and can be found under the name [Aviation Formulary V1.46](http://www.edwilliams.org/avform.htm).
